==> pgformatter_4.2.orig.tar.gz: pgFormatter-4.2/t/pg-test-files/expected/interval.sql <==
--
-- INTERVAL
--

SET DATESTYLE = 'ISO';

SET IntervalStyle TO postgres;

-- check acceptance of "time zone style"
SELECT
    INTERVAL '01:00' AS "One hour";

SELECT
    INTERVAL '+02:00' AS "Two hours";

SELECT
    INTERVAL '-08:00' AS "Eight hours";

SELECT
    INTERVAL '-1 +02:03' AS "22 hours ago...";

SELECT
    INTERVAL '-1 days +02:03' AS "22 hours ago...";

SELECT
    INTERVAL '1.5 weeks' AS "Ten days twelve hours";

SELECT
    INTERVAL '1.5 months' AS "One month 15 days";

SELECT
    INTERVAL '10 years -11 month -12 days +13:14' AS "9 years...";

CREATE TABLE INTERVAL_TBL (
    f1 interval
);

INSERT INTO INTERVAL_TBL (f1)
    VALUES ('@ 1 minute');

INSERT INTO INTERVAL_TBL (f1)
    VALUES ('@ 5 hour');

INSERT INTO INTERVAL_TBL (f1)
    VALUES ('@ 10 day');

INSERT INTO INTERVAL_TBL (f1)
    VALUES ('@ 34 year');

INSERT INTO INTERVAL_TBL (f1)
    VALUES ('@ 3 months');

INSERT INTO INTERVAL_TBL (f1)
    VALUES ('@ 14 seconds ago');

INSERT INTO INTERVAL_TBL (f1)
    VALUES ('1 day 2 hours 3 minutes 4 seconds');

INSERT INTO INTERVAL_TBL (f1)
    VALUES ('6 years');

INSERT INTO INTERVAL_TBL (f1)
    VALUES ('5 months');

INSERT INTO INTERVAL_TBL (f1)
    VALUES ('5 months 12 hours');

-- badly formatted interval
INSERT INTO INTERVAL_TBL (f1)
    VALUES ('badly formatted interval');

INSERT INTO INTERVAL_TBL (f1)
    VALUES ('@ 30 eons ago');

-- test interval operators
SELECT
    '' AS ten,
    *
FROM
    INTERVAL_TBL;

SELECT
    '' AS nine,
    *
FROM
    INTERVAL_TBL
WHERE
    INTERVAL_TBL.f1 <> interval '@ 10 days';

SELECT
    '' AS three,
    *
FROM
    INTERVAL_TBL
WHERE
    INTERVAL_TBL.f1 <= interval '@ 5 hours';

SELECT
    '' AS three,
    *
FROM
    INTERVAL_TBL
WHERE
    INTERVAL_TBL.f1 < interval '@ 1 day';

SELECT
    '' AS one,
    *
FROM
    INTERVAL_TBL
WHERE
    INTERVAL_TBL.f1 = interval '@ 34 years';

SELECT
    '' AS five,
    *
FROM
    INTERVAL_TBL
WHERE
    INTERVAL_TBL.f1 >= interval '@ 1 month';

SELECT
    '' AS nine,
    *
FROM
    INTERVAL_TBL
WHERE
    INTERVAL_TBL.f1 > interval '@ 3 seconds ago';

SELECT
    '' AS fortyfive,
    r1.*,
    r2.*
FROM
    INTERVAL_TBL r1,
    INTERVAL_TBL r2
WHERE
    r1.f1 > r2.f1
ORDER BY
    r1.f1,
    r2.f1;

-- Test intervals that are large enough to overflow 64 bits in comparisons
CREATE TEMP TABLE INTERVAL_TBL_OF (
    f1 interval
);

INSERT INTO INTERVAL_TBL_OF (f1)
    VALUES ('2147483647 days 2147483647 months'), ('2147483647 days -2147483648 months'), ('1 year'), ('-2147483648 days 2147483647 months'), ('-2147483648 days -2147483648 months');

-- these should fail as out-of-range
INSERT INTO INTERVAL_TBL_OF (f1)
    VALUES ('2147483648 days');

INSERT INTO INTERVAL_TBL_OF (f1)
    VALUES ('-2147483649 days');

INSERT INTO INTERVAL_TBL_OF (f1)
    VALUES ('2147483647 years');

INSERT INTO INTERVAL_TBL_OF (f1)
    VALUES ('-2147483648 years');

SELECT
    r1.*,
    r2.*
FROM
    INTERVAL_TBL_OF r1,
    INTERVAL_TBL_OF r2
WHERE
    r1.f1 > r2.f1
ORDER BY
    r1.f1,
    r2.f1;

CREATE INDEX ON INTERVAL_TBL_OF USING btree (f1);

SET enable_seqscan TO FALSE;

EXPLAIN (
    COSTS OFF
)
SELECT
    f1
FROM
    INTERVAL_TBL_OF r1
ORDER BY
    f1;

SELECT
    f1
FROM
    INTERVAL_TBL_OF r1
ORDER BY
    f1;

RESET enable_seqscan;

DROP TABLE INTERVAL_TBL_OF;

-- Test multiplication and division with intervals.
-- Floating point arithmetic rounding errors can lead to unexpected results,
-- though the code attempts to do the right thing and round up to days and
-- minutes to avoid results such as '3 days 24:00 hours' or '14:20:60'.
-- Note that it is expected for some day components to be greater than 29 and
-- some time components be greater than 23:59:59 due to how intervals are
-- stored internally.

CREATE TABLE INTERVAL_MULDIV_TBL (
    span interval
);

SELECT
    span * 0.3 AS product
FROM
    INTERVAL_MULDIV_TBL;

SELECT
    span * 8.2 AS product
FROM
    INTERVAL_MULDIV_TBL;

SELECT
    span / 10 AS quotient
FROM
    INTERVAL_MULDIV_TBL;

SELECT
    span / 100 AS quotient
FROM
    INTERVAL_MULDIV_TBL;

DROP TABLE INTERVAL_MULDIV_TBL;

SET DATESTYLE = 'postgres';

SET IntervalStyle TO postgres_verbose;

SELECT
    '' AS ten,
    *
FROM
    INTERVAL_TBL;

-- test avg(interval), which is somewhat fragile since people have been
-- known to change the allowed input syntax for type interval without
-- updating pg_aggregate.agginitval

SELECT
    avg(f1)
FROM
    interval_tbl;

-- test long interval input
SELECT
    '4 millenniums 5 centuries 4 decades 1 year 4 months 4 days 17 minutes 31 seconds'::interval;

-- test long interval output
-- Note: the actual maximum length of the interval output is longer,
-- but we need the test to work for both integer and floating-point
-- timestamps.

SELECT
    '100000000y 10mon -1000000000d -100000h -10min -10.000001s ago'::interval;

-- test justify_hours() and justify_days()
SELECT
    justify_hours(interval '6 months 3 days 52 hours 3 minutes 2 seconds') AS "6 mons 5 days 4 hours 3 mins 2 seconds";

SELECT
    justify_days(interval '6 months 36 days 5 hours 4 minutes 3 seconds') AS "7 mons 6 days 5 hours 4 mins 3 seconds";

-- test justify_interval()
SELECT
    justify_interval(interval '1 month -1 hour') AS "1 month -1 hour";

-- test fractional second input, and detection of duplicate units
SET DATESTYLE = 'ISO';

SET IntervalStyle TO postgres;

SELECT
    '1 millisecond'::interval,
    '1 microsecond'::interval,
    '500 seconds 99 milliseconds 51 microseconds'::interval;

SELECT
    '3 days 5 milliseconds'::interval;

SELECT
    '1 second 2 seconds'::interval;

-- error
SELECT
    '10 milliseconds 20 milliseconds'::interval;

-- error
SELECT
    '5.5 seconds 3 milliseconds'::interval;

-- error
SELECT
    '1:20:05 5 microseconds'::interval;

-- error
SELECT
    '1 day 1 day'::interval;

-- error
SELECT
    interval '1-2';

-- SQL year-month literal
SELECT
    interval '999' second;

-- oversize leading field is ok
SELECT
    interval '999' minute;

SELECT
    interval '999' hour;

SELECT
    interval '999' day;

SELECT
    interval '999' month;

-- test SQL-spec syntaxes for restricted field sets
SELECT
    interval '1' year;

SELECT
    interval '2' month;

SELECT
    interval '3' day;

SELECT
    interval '4' hour;

SELECT
    interval '5' minute;

SELECT
    interval '6' second;

SELECT
    interval '1' year TO month;

SELECT
    interval '1-2' year TO month;

SELECT
    interval '1 2' day TO hour;

SELECT
    interval '1 2:03' day TO hour;

SELECT
    interval '1 2:03:04' day TO hour;

SELECT
    interval '1 2' day TO minute;

SELECT
    interval '1 2:03' day TO minute;

SELECT
    interval '1 2:03:04' day TO minute;

SELECT
    interval '1 2' day TO second;

SELECT
    interval '1 2:03' day TO second;

SELECT
    interval '1 2:03:04' day TO second;

SELECT
    interval '1 2' hour TO minute;

SELECT
    interval '1 2:03' hour TO minute;

SELECT
    interval '1 2:03:04' hour TO minute;

SELECT
    interval '1 2' hour TO second;

SELECT
    interval '1 2:03' hour TO second;

SELECT
    interval '1 2:03:04' hour TO second;

SELECT
    interval '1 2' minute TO second;

SELECT
    interval '1 2:03' minute TO second;

SELECT
    interval '1 2:03:04' minute TO second;

SELECT
    interval '1 +2:03' minute TO second;

SELECT
    interval '1 +2:03:04' minute TO second;

SELECT
    interval '1 -2:03' minute TO second;

SELECT
    interval '1 -2:03:04' minute TO second;

SELECT
    interval '123 11' day TO hour;

-- ok
SELECT
    interval '123 11' day;

-- not ok
SELECT
    interval '123 11';

-- not ok, too ambiguous
SELECT
    interval '123 2:03 -2:04';

-- not ok, redundant hh:mm fields
-- test syntaxes for restricted precision

SELECT
    interval(0) '1 day 01:23:45.6789';

SELECT
    interval(2) '1 day 01:23:45.6789';

SELECT
    interval '12:34.5678' minute TO second (2);

-- per SQL spec
SELECT
    interval '1.234' second;

SELECT
    interval '1.234' second (2);

SELECT
    interval '1 2.345' day TO second (2);

SELECT
    interval '1 2:03' day TO second (2);

SELECT
    interval '1 2:03.4567' day TO second (2);

SELECT
    interval '1 2:03:04.5678' day TO second (2);

SELECT
    interval '1 2.345' hour TO second (2);

SELECT
    interval '1 2:03.45678' hour TO second (2);

SELECT
    interval '1 2:03:04.5678' hour TO second (2);

SELECT
    interval '1 2.3456' minute TO second (2);

SELECT
    interval '1 2:03.5678' minute TO second (2);

SELECT
    interval '1 2:03:04.5678' minute TO second (2);

-- test casting to restricted precision (bug #14479)
SELECT
    f1,
    f1::INTERVAL DAY TO MINUTE AS "minutes",
    (f1 + interval '1 month')::INTERVAL MONTH::INTERVAL YEAR AS "years"
FROM
    interval_tbl;

-- test inputting and outputting SQL standard interval literals
SET IntervalStyle TO sql_standard;

SELECT
    interval '0' AS "zero",
    interval '1-2' year TO month AS "year-month",
    interval '1 2:03:04' day TO second AS "day-time",
    - interval '1-2' AS "negative year-month",
    - interval '1 2:03:04' AS "negative day-time";

-- test input of some not-quite-standard interval values in the sql style
SET IntervalStyle TO postgres;

SELECT
    interval '+1 -1:00:00',
    interval '-1 +1:00:00',
    interval '+1-2 -3 +4:05:06.789',
    interval '-1-2 +3 -4:05:06.789';

-- test output of couple non-standard interval values in the sql style
SET IntervalStyle TO sql_standard;

SELECT
    interval '1 day -1 hours',
    interval '-1 days +1 hours',
    interval '1 years 2 months -3 days 4 hours 5 minutes 6.789 seconds',
    - interval '1 years 2 months -3 days 4 hours 5 minutes 6.789 seconds';

-- test outputting iso8601 intervals
SET IntervalStyle TO iso_8601;

SELECT
    interval '0' AS "zero",
    interval '1-2' AS "a year 2 months",
    interval '1 2:03:04' AS "a bit over a day",
    interval '2:03:04.45679' AS "a bit over 2 hours",
    (interval '1-2' + interval '3 4:05:06.7') AS "all fields",
    (interval '1-2' - interval '3 4:05:06.7') AS "mixed sign",
    (- interval '1-2' + interval '3 4:05:06.7') AS "negative";

-- test inputting ISO 8601 4.4.2.1 "Format With Time Unit Designators"
SET IntervalStyle TO sql_standard;

SELECT
    interval 'P0Y' AS "zero",
    interval 'P1Y2M' AS "a year 2 months",
    interval 'P1W' AS "a week",
    interval 'P1DT2H3M4S' AS "a bit over a day",
    interval 'P1Y2M3DT4H5M6.7S' AS "all fields",
    interval 'P-1Y-2M-3DT-4H-5M-6.7S' AS "negative",
    interval 'PT-0.1S' AS "fractional second";

-- test inputting ISO 8601 4.4.2.2 "Alternative Format"
SET IntervalStyle TO postgres;

SELECT
    interval 'P00021015T103020' AS "ISO8601 Basic Format",
    interval 'P0002-10-15T10:30:20' AS "ISO8601 Extended Format";

-- Make sure optional ISO8601 alternative format fields are optional.
SELECT
    interval 'P0002' AS "year only",
    interval 'P0002-10' AS "year month",
    interval 'P0002-10-15' AS "year month day",
    interval 'P0002T1S' AS "year only plus time",
    interval 'P0002-10T1S' AS "year month plus time",
    interval 'P0002-10-15T1S' AS "year month day plus time",
    interval 'PT10' AS "hour only",
    interval 'PT10:30' AS "hour minute";

-- test a couple rounding cases that changed since 8.3 w/ HAVE_INT64_TIMESTAMP.
SET IntervalStyle TO postgres_verbose;

SELECT
    interval '-10 mons -3 days +03:55:06.70';

SELECT
    interval '1 year 2 mons 3 days 04:05:06.699999';

SELECT
    interval '0:0:0.7',
    interval '@ 0.70 secs',
    interval '0.7 seconds';

-- check that '30 days' equals '1 month' according to the hash function
SELECT
    '30 days'::interval = '1 month'::interval AS t;

SELECT
    interval_hash('30 days'::interval) = interval_hash('1 month'::interval) AS t;

-- numeric constructor
SELECT
    make_interval(years := 2);

SELECT
    make_interval(years := 1, months := 6);

SELECT
    make_interval(years := 1, months := - 1, weeks := 5, days := - 7, hours := 25, mins := - 180);

SELECT
    make_interval() = make_interval(years := 0, months := 0, weeks := 0, days := 0, mins := 0, secs := 0.0);

SELECT
    make_interval(hours := - 2, mins := - 10, secs := - 25.3);

SELECT
    make_interval(years := 'inf'::float::int);

SELECT
    make_interval(months := 'NaN'::float::int);

SELECT
    make_interval(secs := 'inf');

SELECT
    make_interval(secs := 'NaN');

SELECT
    make_interval(secs := 7e12);

==> pgformatter_4.3.orig.tar.gz: pgFormatter-4.3/t/pg-test-files/expected/interval.sql <==
--
-- INTERVAL
--

SET DATESTYLE = 'ISO';

SET IntervalStyle TO postgres;

-- check acceptance of "time zone style"
SELECT
    INTERVAL '01:00' AS "One hour";

SELECT
    INTERVAL '+02:00' AS "Two hours";

SELECT
    INTERVAL '-08:00' AS "Eight hours";

SELECT
    INTERVAL '-1 +02:03' AS "22 hours ago...";

SELECT
    INTERVAL '-1 days +02:03' AS "22 hours ago...";

SELECT
    INTERVAL '1.5 weeks' AS "Ten days twelve hours";

SELECT
    INTERVAL '1.5 months' AS "One month 15 days";

SELECT
    INTERVAL '10 years -11 month -12 days +13:14' AS "9 years...";

CREATE TABLE INTERVAL_TBL (
    f1 interval
);

INSERT INTO INTERVAL_TBL (f1)
    VALUES ('@ 1 minute');

INSERT INTO INTERVAL_TBL (f1)
    VALUES ('@ 5 hour');

INSERT INTO INTERVAL_TBL (f1)
    VALUES ('@ 10 day');

INSERT INTO INTERVAL_TBL (f1)
    VALUES ('@ 34 year');

INSERT INTO INTERVAL_TBL (f1)
    VALUES ('@ 3 months');

INSERT INTO INTERVAL_TBL (f1)
    VALUES ('@ 14 seconds ago');

INSERT INTO INTERVAL_TBL (f1)
    VALUES ('1 day 2 hours 3 minutes 4 seconds');

INSERT INTO INTERVAL_TBL (f1)
    VALUES ('6 years');

INSERT INTO INTERVAL_TBL (f1)
    VALUES ('5 months');

INSERT INTO INTERVAL_TBL (f1)
    VALUES ('5 months 12 hours');

-- badly formatted interval
INSERT INTO INTERVAL_TBL (f1)
    VALUES ('badly formatted interval');

INSERT INTO INTERVAL_TBL (f1)
    VALUES ('@ 30 eons ago');

-- test interval operators
SELECT
    '' AS ten,
    *
FROM
    INTERVAL_TBL;

SELECT
    '' AS nine,
    *
FROM
    INTERVAL_TBL
WHERE
    INTERVAL_TBL.f1 <> interval '@ 10 days';

SELECT
    '' AS three,
    *
FROM
    INTERVAL_TBL
WHERE
    INTERVAL_TBL.f1 <= interval '@ 5 hours';

SELECT
    '' AS three,
    *
FROM
    INTERVAL_TBL
WHERE
    INTERVAL_TBL.f1 < interval '@ 1 day';

SELECT
    '' AS one,
    *
FROM
    INTERVAL_TBL
WHERE
    INTERVAL_TBL.f1 = interval '@ 34 years';

SELECT
    '' AS five,
    *
FROM
    INTERVAL_TBL
WHERE
    INTERVAL_TBL.f1 >= interval '@ 1 month';

SELECT
    '' AS nine,
    *
FROM
    INTERVAL_TBL
WHERE
    INTERVAL_TBL.f1 > interval '@ 3 seconds ago';

SELECT
    '' AS fortyfive,
    r1.*,
    r2.*
FROM
    INTERVAL_TBL r1,
    INTERVAL_TBL r2
WHERE
    r1.f1 > r2.f1
ORDER BY
    r1.f1,
    r2.f1;

-- Test intervals that are large enough to overflow 64 bits in comparisons
CREATE TEMP TABLE INTERVAL_TBL_OF (
    f1 interval
);

INSERT INTO INTERVAL_TBL_OF (f1)
    VALUES ('2147483647 days 2147483647 months'), ('2147483647 days -2147483648 months'), ('1 year'), ('-2147483648 days 2147483647 months'), ('-2147483648 days -2147483648 months');

-- these should fail as out-of-range
INSERT INTO INTERVAL_TBL_OF (f1)
    VALUES ('2147483648 days');

INSERT INTO INTERVAL_TBL_OF (f1)
    VALUES ('-2147483649 days');

INSERT INTO INTERVAL_TBL_OF (f1)
    VALUES ('2147483647 years');

INSERT INTO INTERVAL_TBL_OF (f1)
    VALUES ('-2147483648 years');

SELECT
    r1.*,
    r2.*
FROM
    INTERVAL_TBL_OF r1,
    INTERVAL_TBL_OF r2
WHERE
    r1.f1 > r2.f1
ORDER BY
    r1.f1,
    r2.f1;

CREATE INDEX ON INTERVAL_TBL_OF USING btree (f1);

SET enable_seqscan TO FALSE;

EXPLAIN (
    COSTS OFF
)
SELECT
    f1
FROM
    INTERVAL_TBL_OF r1
ORDER BY
    f1;

SELECT
    f1
FROM
    INTERVAL_TBL_OF r1
ORDER BY
    f1;

RESET enable_seqscan;

DROP TABLE INTERVAL_TBL_OF;

-- Test multiplication and division with intervals.
-- Floating point arithmetic rounding errors can lead to unexpected results,
-- though the code attempts to do the right thing and round up to days and
-- minutes to avoid results such as '3 days 24:00 hours' or '14:20:60'.
-- Note that it is expected for some day components to be greater than 29 and
-- some time components be greater than 23:59:59 due to how intervals are
-- stored internally.

CREATE TABLE INTERVAL_MULDIV_TBL (
    span interval
);

SELECT
    span * 0.3 AS product
FROM
    INTERVAL_MULDIV_TBL;

SELECT
    span * 8.2 AS product
FROM
    INTERVAL_MULDIV_TBL;

SELECT
    span / 10 AS quotient
FROM
    INTERVAL_MULDIV_TBL;

SELECT
    span / 100 AS quotient
FROM
    INTERVAL_MULDIV_TBL;

DROP TABLE INTERVAL_MULDIV_TBL;

SET DATESTYLE = 'postgres';

SET IntervalStyle TO postgres_verbose;

SELECT
    '' AS ten,
    *
FROM
    INTERVAL_TBL;

-- test avg(interval), which is somewhat fragile since people have been
-- known to change the allowed input syntax for type interval without
-- updating pg_aggregate.agginitval

SELECT
    avg(f1)
FROM
    interval_tbl;

-- test long interval input
SELECT
    '4 millenniums 5 centuries 4 decades 1 year 4 months 4 days 17 minutes 31 seconds'::interval;

-- test long interval output
-- Note: the actual maximum length of the interval output is longer,
-- but we need the test to work for both integer and floating-point
-- timestamps.

SELECT
    '100000000y 10mon -1000000000d -100000h -10min -10.000001s ago'::interval;

-- test justify_hours() and justify_days()
SELECT
    justify_hours(interval '6 months 3 days 52 hours 3 minutes 2 seconds') AS "6 mons 5 days 4 hours 3 mins 2 seconds";

SELECT
    justify_days(interval '6 months 36 days 5 hours 4 minutes 3 seconds') AS "7 mons 6 days 5 hours 4 mins 3 seconds";

-- test justify_interval()
SELECT
    justify_interval(interval '1 month -1 hour') AS "1 month -1 hour";

-- test fractional second input, and detection of duplicate units
SET DATESTYLE = 'ISO';

SET IntervalStyle TO postgres;

SELECT
    '1 millisecond'::interval,
    '1 microsecond'::interval,
    '500 seconds 99 milliseconds 51 microseconds'::interval;

SELECT
    '3 days 5 milliseconds'::interval;

SELECT
    '1 second 2 seconds'::interval;

-- error
SELECT
    '10 milliseconds 20 milliseconds'::interval;

-- error
SELECT
    '5.5 seconds 3 milliseconds'::interval;

-- error
SELECT
    '1:20:05 5 microseconds'::interval;

-- error
SELECT
    '1 day 1 day'::interval;

-- error
SELECT
    interval '1-2';

-- SQL year-month literal
SELECT
    interval '999' second;

-- oversize leading field is ok
SELECT
    interval '999' minute;

SELECT
    interval '999' hour;

SELECT
    interval '999' day;

SELECT
    interval '999' month;

-- test SQL-spec syntaxes for restricted field sets
SELECT
    interval '1' year;

SELECT
    interval '2' month;

SELECT
    interval '3' day;

SELECT
    interval '4' hour;

SELECT
    interval '5' minute;

SELECT
    interval '6' second;

SELECT
    interval '1' year TO month;

SELECT
    interval '1-2' year TO month;

SELECT
    interval '1 2' day TO hour;

SELECT
    interval '1 2:03' day TO hour;

SELECT
    interval '1 2:03:04' day TO hour;

SELECT
    interval '1 2' day TO minute;

SELECT
    interval '1 2:03' day TO minute;

SELECT
    interval '1 2:03:04' day TO minute;

SELECT
    interval '1 2' day TO second;

SELECT
    interval '1 2:03' day TO second;

SELECT
    interval '1 2:03:04' day TO second;

SELECT
    interval '1 2' hour TO minute;

SELECT
    interval '1 2:03' hour TO minute;

SELECT
    interval '1 2:03:04' hour TO minute;

SELECT
    interval '1 2' hour TO second;

SELECT
    interval '1 2:03' hour TO second;

SELECT
    interval '1 2:03:04' hour TO second;

SELECT
    interval '1 2' minute TO second;

SELECT
    interval '1 2:03' minute TO second;

SELECT
    interval '1 2:03:04' minute TO second;

SELECT
    interval '1 +2:03' minute TO second;

SELECT
    interval '1 +2:03:04' minute TO second;

SELECT
    interval '1 -2:03' minute TO second;

SELECT
    interval '1 -2:03:04' minute TO second;

SELECT
    interval '123 11' day TO hour;

-- ok
SELECT
    interval '123 11' day;

-- not ok
SELECT
    interval '123 11';

-- not ok, too ambiguous
SELECT
    interval '123 2:03 -2:04';

-- not ok, redundant hh:mm fields
-- test syntaxes for restricted precision

SELECT
    interval(0) '1 day 01:23:45.6789';

SELECT
    interval(2) '1 day 01:23:45.6789';

SELECT
    interval '12:34.5678' minute TO second (2);

-- per SQL spec
SELECT
    interval '1.234' second;

SELECT
    interval '1.234' second (2);

SELECT
    interval '1 2.345' day TO second (2);

SELECT
    interval '1 2:03' day TO second (2);

SELECT
    interval '1 2:03.4567' day TO second (2);

SELECT
    interval '1 2:03:04.5678' day TO second (2);

SELECT
    interval '1 2.345' hour TO second (2);

SELECT
    interval '1 2:03.45678' hour TO second (2);

SELECT
    interval '1 2:03:04.5678' hour TO second (2);

SELECT
    interval '1 2.3456' minute TO second (2);

SELECT
    interval '1 2:03.5678' minute TO second (2);

SELECT
    interval '1 2:03:04.5678' minute TO second (2);

-- test casting to restricted precision (bug #14479)
SELECT
    f1,
    f1::interval DAY TO MINUTE AS "minutes",
    (f1 + interval '1 month')::interval MONTH::interval YEAR AS "years"
FROM
    interval_tbl;

-- test inputting and outputting SQL standard interval literals
SET IntervalStyle TO sql_standard;

SELECT
    interval '0' AS "zero",
    interval '1-2' year TO month AS "year-month",
    interval '1 2:03:04' day TO second AS "day-time",
    - interval '1-2' AS "negative year-month",
    - interval '1 2:03:04' AS "negative day-time";

-- test input of some not-quite-standard interval values in the sql style
SET IntervalStyle TO postgres;

SELECT
    interval '+1 -1:00:00',
    interval '-1 +1:00:00',
    interval '+1-2 -3 +4:05:06.789',
    interval '-1-2 +3 -4:05:06.789';

-- test output of couple non-standard interval values in the sql style
SET IntervalStyle TO sql_standard;

SELECT
    interval '1 day -1 hours',
    interval '-1 days +1 hours',
    interval '1 years 2 months -3 days 4 hours 5 minutes 6.789 seconds',
    - interval '1 years 2 months -3 days 4 hours 5 minutes 6.789 seconds';

-- test outputting iso8601 intervals
SET IntervalStyle TO iso_8601;

SELECT
    interval '0' AS "zero",
    interval '1-2' AS "a year 2 months",
    interval '1 2:03:04' AS "a bit over a day",
    interval '2:03:04.45679' AS "a bit over 2 hours",
    (interval '1-2' + interval '3 4:05:06.7') AS "all fields",
    (interval '1-2' - interval '3 4:05:06.7') AS "mixed sign",
    (- interval '1-2' + interval '3 4:05:06.7') AS "negative";

-- test inputting ISO 8601 4.4.2.1 "Format With Time Unit Designators"
SET IntervalStyle TO sql_standard;

SELECT
    interval 'P0Y' AS "zero",
    interval 'P1Y2M' AS "a year 2 months",
    interval 'P1W' AS "a week",
    interval 'P1DT2H3M4S' AS "a bit over a day",
    interval 'P1Y2M3DT4H5M6.7S' AS "all fields",
    interval 'P-1Y-2M-3DT-4H-5M-6.7S' AS "negative",
    interval 'PT-0.1S' AS "fractional second";

-- test inputting ISO 8601 4.4.2.2 "Alternative Format"
SET IntervalStyle TO postgres;

SELECT
    interval 'P00021015T103020' AS "ISO8601 Basic Format",
    interval 'P0002-10-15T10:30:20' AS "ISO8601 Extended Format";

-- Make sure optional ISO8601 alternative format fields are optional.
SELECT
    interval 'P0002' AS "year only",
    interval 'P0002-10' AS "year month",
    interval 'P0002-10-15' AS "year month day",
    interval 'P0002T1S' AS "year only plus time",
    interval 'P0002-10T1S' AS "year month plus time",
    interval 'P0002-10-15T1S' AS "year month day plus time",
    interval 'PT10' AS "hour only",
    interval 'PT10:30' AS "hour minute";

-- test a couple rounding cases that changed since 8.3 w/ HAVE_INT64_TIMESTAMP.
SET IntervalStyle TO postgres_verbose;

SELECT
    interval '-10 mons -3 days +03:55:06.70';

SELECT
    interval '1 year 2 mons 3 days 04:05:06.699999';

SELECT
    interval '0:0:0.7',
    interval '@ 0.70 secs',
    interval '0.7 seconds';

-- check that '30 days' equals '1 month' according to the hash function
SELECT
    '30 days'::interval = '1 month'::interval AS t;

SELECT
    interval_hash('30 days'::interval) = interval_hash('1 month'::interval) AS t;

-- numeric constructor
SELECT
    make_interval(years := 2);

SELECT
    make_interval(years := 1, months := 6);

SELECT
    make_interval(years := 1, months := - 1, weeks := 5, days := - 7, hours := 25, mins := - 180);

SELECT
    make_interval() = make_interval(years := 0, months := 0, weeks := 0, days := 0, mins := 0, secs := 0.0);

SELECT
    make_interval(hours := - 2, mins := - 10, secs := - 25.3);

SELECT
    make_interval(years := 'inf'::float::int);

SELECT
    make_interval(months := 'NaN'::float::int);

SELECT
    make_interval(secs := 'inf');

SELECT
    make_interval(secs := 'NaN');

SELECT
    make_interval(secs := 7e12);
